@@ -18,14 +18,16 @@ load_stuff <- function() {
   assign(".rgdal_old.GDAL_DATA", Sys.getenv("GDAL_DATA"), envir=.RGDAL_CACHE)
   assign(".rgdal_old.NEEDED", FALSE, envir=.RGDAL_CACHE)
   if (file.exists(system.file("proj/nad.lst", package = "rgdal")[1])) {
-  prj = system.file("proj", package = "rgdal")[1]
-    if (PROJis6ormore() && 
-      .Call("PROJ4VersionInfo", PACKAGE="rgdal")[[2]] < 700) {
+    prj = system.file("proj", package = "rgdal")[1]
+    if (PROJis6ormore() #&& 
+#      .Call("PROJ4VersionInfo", PACKAGE="rgdal")[[2]] < 700
+    ) {
       set_is <- set_proj_search_paths(prj)
+      assign(".rgdal_set.PROJ_LIB", set_is, envir=.RGDAL_CACHE)
     } else {
       Sys.setenv("PROJ_LIB"=prj)
+      assign(".rgdal_set.PROJ_LIB", Sys.getenv("PROJ_LIB"), envir=.RGDAL_CACHE)
     }
-    assign(".rgdal_set.PROJ_LIB", Sys.getenv("PROJ_LIB"), envir=.RGDAL_CACHE)
     Sys.setenv("GDAL_DATA"=system.file("gdal", package = "rgdal")[1])
     assign(".rgdal_set.GDAL_DATA", Sys.getenv("GDAL_DATA"),
       envir=.RGDAL_CACHE)
@@ -42,6 +44,7 @@ load_stuff <- function() {
   assign("thin_PROJ6_warnings", FALSE, envir=.RGDAL_CACHE)
   assign("PROJ6_warnings_count", 0L, envir=.RGDAL_CACHE)
   assign("enforce_xy", TRUE, envir=.RGDAL_CACHE)
+  assign("prefer_proj", TRUE, envir=.RGDAL_CACHE)
   rgdal_show_exportToProj4_warnings <- options("rgdal_show_exportToProj4_warnings")
   if (!is.null(rgdal_show_exportToProj4_warnings)) {
     if (!(rgdal_show_exportToProj4_warnings %in% c("all", "thin", "none"))) {
@@ -90,7 +93,7 @@ local_RGDAL_Init <- function() .Call('RGDAL_Init', PACKAGE="rgdal")
     assign("has_proj_def.dat", pdd, envir=.RGDAL_CACHE)
   }
 
-  Smess <- paste('rgdal: version: ',
+  Smess <- paste('Please note that rgdal will be retired by the end of 2023,\nplan transition to sf/stars/terra functions using GDAL and PROJ\nat your earliest convenience.\n\n', 'rgdal: version: ',
     utils::packageDescription("rgdal")$Version,
     ', (SVN revision ', svn_version, ')\n',
     'Geospatial Data Abstraction Library ',
@@ -117,8 +120,9 @@ local_RGDAL_Init <- function() .Call('RGDAL_Init', PACKAGE="rgdal")
     spVcheck <- utils::packageVersion("sp") == splVersion
   if (!is.null(spVcheck) && !spVcheck) paste(Smess, 
     "sp version used to install rgdal and loaded sp version differ\n")
-  if (PROJis6ormore()) Smess <- paste(Smess, "To mute warnings of possible GDAL/OSR exportToProj4() degradation,\nuse options(\"rgdal_show_exportToProj4_warnings\"=\"none\") before loading rgdal.\n", sep="")
-  if (nzchar(get(".rgdal_set.PROJ_LIB", envir=.RGDAL_CACHE))) {
+  if (PROJis6ormore()) Smess <- paste(Smess, "To mute warnings of possible GDAL/OSR exportToProj4() degradation,\nuse options(\"rgdal_show_exportToProj4_warnings\"=\"none\") before loading sp or rgdal.\n", sep="")
+  if (nzchar(get(".rgdal_set.PROJ_LIB", envir=.RGDAL_CACHE)) &&
+      !PROJis6ormore()) {
     Smess <- paste(Smess, "Overwritten PROJ_LIB was ",
       get(".rgdal_set.PROJ_LIB", envir=.RGDAL_CACHE), "\n", sep="")
   }
@@ -128,14 +132,23 @@ local_RGDAL_Init <- function() .Call('RGDAL_Init', PACKAGE="rgdal")
 #.Last.lib <- function(lib, pkg) {
 .onUnload <- function(libpath) {
   if (get(".rgdal_old.NEEDED", envir=.RGDAL_CACHE)) {
-    Sys.setenv("PROJ_LIB"=get(".rgdal_old.PROJ_LIB", envir=.RGDAL_CACHE))
+    prj = get(".rgdal_old.PROJ_LIB", envir=.RGDAL_CACHE)
+    if (PROJis6ormore() #&& 
+#      .Call("PROJ4VersionInfo", PACKAGE="rgdal")[[2]] < 700
+    ) {
+      set_is <- set_proj_search_paths(prj)
+    } else {
+      Sys.setenv("PROJ_LIB"=prj)
+    }
     Sys.setenv("GDAL_DATA"=get(".rgdal_old.GDAL_DATA", envir=.RGDAL_CACHE))
   }
   .Call('RGDAL_Exit', PACKAGE="rgdal")
 }
 
 rgdal_extSoftVersion <- function() {
+  epsg_version <- EPSG_version()
   res <- c("GDAL"=strsplit(strsplit(getGDALVersionInfo(), ",")[[1]][1], " ")[[1]][2], "GDAL_with_GEOS"=as.character(getGDALwithGEOS()), "PROJ"=strsplit(strsplit(getPROJ4VersionInfo(), ",")[[1]][1], " ")[[1]][2], "sp"=version_sp_linkingTo())
+  if (!is.null(epsg_version)) res <- c(res, "EPSG"=epsg_version)
   res
 }
 
