@@ -417,7 +417,7 @@ setMethod('dim', 'GDALReadOnlyDataset',
               c(nrows, ncols)
           })
 
-getProjectionRef <- function(dataset, OVERRIDE_PROJ_DATUM_WITH_TOWGS84=NULL, enforce_xy=NULL) {
+getProjectionRef <- function(dataset, OVERRIDE_PROJ_DATUM_WITH_TOWGS84=NULL, enforce_xy=NULL, get_source_if_boundcrs=TRUE) {
 
   assertClass(dataset, 'GDALReadOnlyDataset')
 
@@ -448,7 +448,7 @@ getProjectionRef <- function(dataset, OVERRIDE_PROJ_DATUM_WITH_TOWGS84=NULL, enf
     res <- .Call('RGDAL_GetProjectionRef', dataset, enforce_xy, PACKAGE="rgdal")
   }
   no_ellps <- FALSE
-  if (!(nchar(res) == 0L) && new_proj_and_gdal()) {
+  if (!(is.na(res)) && new_proj_and_gdal()) {
     no_towgs84 <- all(nchar(attr(res, "towgs84")) == 0)
     if ((length(grep("towgs84", c(res))) == 0L) && !no_towgs84)
       warning("TOWGS84 discarded")
@@ -458,7 +458,7 @@ getProjectionRef <- function(dataset, OVERRIDE_PROJ_DATUM_WITH_TOWGS84=NULL, enf
     no_ellps <- no_ellps && length(grep("datum", c(res))) == 0L
     if (no_ellps) {
       msg <- paste0("Discarded ellps ", attr(res, "ellps"),
-            " in CRS definition: ", c(res))
+            " in Proj4 definition: ", c(res))
       if (get_rgdal_show_exportToProj4_warnings()) {
        if (!get_thin_PROJ6_warnings()) {
         warning(msg)
@@ -474,11 +474,11 @@ getProjectionRef <- function(dataset, OVERRIDE_PROJ_DATUM_WITH_TOWGS84=NULL, enf
          }
     }
 # warning("Discarded ellps ", attr(res, "ellps"),
-#            " in CRS definition: ", c(res))
+#            " in Proj4 definition: ", c(res))
     if ((!is.null(attr(res, "datum"))) && (nchar(attr(res, "datum")) > 0L)
       && (length(grep("datum", c(res))) == 0L)) {
       msg <- paste0("Discarded datum ", attr(res, "datum"),
-          " in CRS definition: ", c(res))
+          " in Proj4 definition: ", c(res))
       if (!no_towgs84 && (length(grep("towgs84", c(res))) > 0L))
         msg <- paste0(msg, ",\n but +towgs84= values preserved")
       if (get_P6_datum_hard_fail()) stop(msg)
@@ -499,7 +499,16 @@ getProjectionRef <- function(dataset, OVERRIDE_PROJ_DATUM_WITH_TOWGS84=NULL, enf
         }
 #warning(msg)
     }
-    if (new_proj_and_gdal()) wkt2 <- attr(res, "WKT2_2018")
+    if (new_proj_and_gdal()) {
+      wkt2 <- attr(res, "WKT2_2018")
+      if (get_source_if_boundcrs) {
+        if (length(grep("^BOUNDCRS", wkt2)) > 0L) {
+          wkt2a <- try(.Call("get_source_crs", wkt2, PACKAGE="rgdal"),
+            silent=TRUE)
+          if (!inherits(wkt2a, "try-error")) wkt2 <- wkt2a
+        }
+      }
+    }
   }
   res <- c(res)
   if (new_proj_and_gdal()) {
