@@ -9,7 +9,7 @@
 #
 ogrInfo <- function(dsn, layer, encoding=NULL,
   use_iconv=FALSE, swapAxisOrder=FALSE, require_geomType=NULL,
-  morphFromESRI=NULL, dumpSRS=FALSE, enforce_xy=NULL) {
+  morphFromESRI=NULL, dumpSRS=FALSE, enforce_xy=NULL, D3_if_2D3D_points=FALSE) {
   if (missing(dsn)) stop("missing dsn")
   stopifnot(is.character(dsn))
   stopifnot(length(dsn) == 1L)
@@ -105,9 +105,17 @@ ogrInfo <- function(dsn, layer, encoding=NULL,
 
       u_eType <- unique(sort(eType))
       u_with_z <- unique(sort(with_z))
-      if (length(u_with_z) != 1L) stop(
-        paste("Multiple # dimensions:", 
-          paste((u_with_z + 2), collapse=":")))
+      attr(u_with_z, "elevated") <- FALSE
+      if (length(u_with_z) != 1L) {
+        if (D3_if_2D3D_points) {
+          warning("Accepting mixed 2D and 3D as 3D")
+          u_with_z <- 1L
+          attr(u_with_z, "elevated") <- TRUE
+        } else {
+          stop(paste("Multiple # dimensions:", paste((u_with_z + 2),
+          collapse=":")))
+        }
+      }
       if (u_with_z < 0 || u_with_z > 1) stop(
         paste("Invalid # dimensions:", (u_with_z + 2)))
 
@@ -251,7 +259,7 @@ ogrDrivers <- function() {
 }
 
 OGRSpatialRef <- function(dsn, layer, morphFromESRI=NULL, dumpSRS=FALSE,
-  driver=NULL, enforce_xy=NULL) {
+  driver=NULL, enforce_xy=NULL, get_source_if_boundcrs=TRUE) {
   stopifnot(is.character(dsn))
   stopifnot(length(dsn) == 1L)
   if (is.null(driver)) driver <- attr(ogrListLayers(dsn), "driver")
@@ -293,7 +301,7 @@ OGRSpatialRef <- function(dsn, layer, morphFromESRI=NULL, dumpSRS=FALSE,
     no_ellps <- no_ellps && length(grep("datum", c(res))) == 0L
     if (no_ellps) {
       msg <- paste0("Discarded ellps ", attr(res, "ellps"),
-            " in CRS definition: ", c(res))
+            " in Proj4 definition: ", c(res))
       if (get_rgdal_show_exportToProj4_warnings()) {
        if (!get_thin_PROJ6_warnings()) {
         warning(msg)
@@ -311,7 +319,7 @@ OGRSpatialRef <- function(dsn, layer, morphFromESRI=NULL, dumpSRS=FALSE,
     if ((!is.null(attr(res, "datum"))) && (nchar(attr(res, "datum")) > 0L)
       && (length(grep("datum", c(res))) == 0L)) {
       msg <- paste0("Discarded datum ", attr(res, "datum"),
-          " in CRS definition: ", c(res))
+          " in Proj4 definition: ", c(res))
       if (!no_towgs84 && (length(grep("towgs84", c(res))) > 0L))
         msg <- paste0(msg, ",\n but +towgs84= values preserved")
       if (get_P6_datum_hard_fail()) stop(msg)
@@ -332,7 +340,16 @@ OGRSpatialRef <- function(dsn, layer, morphFromESRI=NULL, dumpSRS=FALSE,
         }
 #warning(msg)
     }
-    if (new_proj_and_gdal()) wkt2 <- attr(res, "WKT2_2018")
+    if (new_proj_and_gdal()) {
+      wkt2 <- attr(res, "WKT2_2018")
+      if (get_source_if_boundcrs) {
+        if (length(grep("^BOUNDCRS", wkt2)) > 0L) {
+          wkt2a <- try(.Call("get_source_crs", wkt2, PACKAGE="rgdal"),
+            silent=TRUE)
+          if (!inherits(wkt2a, "try-error")) wkt2 <- wkt2a
+        }
+      }
+    }
   }
   res <- c(res)
   if (new_proj_and_gdal()) {
